# limit parallel builds
%define _smp_build_ncpus 4

# "fix" lua underlinking:
%define _disable_ld_no_undefined 1

%define url_ver %(echo %{version}|cut -d. -f1,2)

# python are templates which cannot be byte compiled
%define _python_bytecompile_build 0

# filter out plugin .so from provides
# Exclude privlibs
%global __provides_exclude_from ^%{_libdir}/gnome-builder

%global privlibs .*-private|libide|libgnome-builder-plugins
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^(%{privlibs}).*\\.so.*

# filter out private typelib(Ide) require
%global __requires_exclude  %{?__requires_exclude:%__requires_exclude|}^typelib\\(Ide\\)

%global libdazzle_version 3.33.90
%global glib2_version 2.61.2
%global gtk3_version 3.22.26
%global json_glib_version 1.2.0
%global jsonrpc_glib_version 3.29.91
%global libpeas_version 1.22.0
%global template_glib_version 3.28.0
%global libgit2_glib_version 0.28.0.1
%global devhelp_version 3.25.1
%global sysprof_version 3.37.1

Name:		gnome-builder
Version:	3.38.2
Release:	%mkrel 1
Summary:	IDE for writing GNOME-based software
# Note: Checked as of 3.20.2
#
# Most of GNOME Builder is licensed under the GPLv3+.
#
# Others are easy to identify
#
# The following files are MIT licensed:
#     - src/resources/css/markdown.css
#     - src/resources/js/marked.js
#
# The following files are licensed under the CC-BY-SA license:
#     - data/icons/
#
# The following files are licensed under the CC0 license:
#     - data/org.gnome.Builder.appdata.xml
#     - data/html-preview.png
License:        GPLv3+ and GPLv2+ and LGPLv3+ and LGPLv2+ and MIT and CC-BY-SA and CC0
Group:		Graphical desktop/GNOME
URL:		https://wiki.gnome.org/Apps/Builder
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
# Upstream patches
BuildRequires:	bison
BuildRequires:	gettext
BuildRequires:	appdata-tools
BuildRequires:	clang-devel
BuildRequires:	docbook-style-xsl
BuildRequires:	flex
BuildRequires:	gsettings-desktop-schemas
BuildRequires:	gtk-doc
BuildRequires:	itstool
BuildRequires:	libxml2-utils
BuildRequires:	llvm-devel
BuildRequires:	locales-en
BuildRequires:	meson
BuildRequires:	pkgconfig(enchant-2)
BuildRequires:	pkgconfig(flatpak)
BuildRequires:  pkgconfig(gio-2.0) >= %{glib2_version}
BuildRequires:	pkgconfig(gladeui-2.0)
BuildRequires:	pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk+-3.0) >= %{gtk3_version}
BuildRequires:	pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(json-glib-1.0) >= %{json_glib_version}
BuildRequires:	pkgconfig(jsonrpc-glib-1.0) >= %{jsonrpc_glib_version}
BuildRequires:  pkgconfig(libdazzle-1.0) >= %{libdazzle_version}
BuildRequires:  pkgconfig(libdevhelp-3.0) >= %{devhelp_version}
BuildRequires:  pkgconfig(libgit2-glib-1.0) >= %{libgit2_glib_version}
BuildRequires:	pkgconfig(libpeas-1.0) >= %{libpeas_version}
BuildRequires:	pkgconfig(libportal)
BuildRequires:	pkgconfig(mm-common-util)
BuildRequires:	pkgconfig(pangoft2)
BuildRequires:	pkgconfig(libpcre)
BuildRequires:	pkgconfig(pygobject-3.0) >= 3.0.0
BuildRequires:	pkgconfig(python3)
BuildRequires:  pkgconfig(sysprof-4) >= %{sysprof_version}
BuildRequires:  pkgconfig(sysprof-capture-4)
BuildRequires:  pkgconfig(sysprof-ui-4) >= %{sysprof_version}
BuildRequires:	pkgconfig(systemd)
BuildRequires:  pkgconfig(template-glib-1.0) >= %{template_glib_version}
BuildRequires:	pkgconfig(vte-2.91)
BuildRequires:	pkgconfig(webkit2gtk-4.0)
BuildRequires:	python3-gobject3
BuildRequires:	python3-sphinx
BuildRequires:	xsltproc
BuildConflicts: valgrind-devel <= 3.13.0-10.mga7

Requires:	gtksourceview >= 4
Requires:	gsettings-desktop-schemas
Requires:	libpeas-loader-python3
Requires:	python3-jedi
# (mga#27464)
Requires:	typelib(Jsonrpc)

Recommends:	flatpak-builder
Recommends:	clang
Recommends:	gnome-code-assistance
Recommends:	meson
Recommends:	sysprof

%description
Builder attempts to be an IDE for writing software for GNOME. It does not try
to be a generic IDE, but one specialized for writing GNOME software.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
export LC_ALL=en_US.UTF-8
%meson -Dhelp=true
%meson_build

%install
%meson_install

%find_lang %{name}

%files -f %{name}.lang
%doc NEWS README.md
%license COPYING
%{_bindir}/*
%{_libdir}/%{name}/
%{_libexecdir}/gnome-builder-clang
%{_libexecdir}/gnome-builder-git
%{_datadir}/applications/org.gnome.Builder.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%{_iconsdir}/*/*/*/*
%{_datadir}/dbus-1/services/org.gnome.Builder.service
%{_datadir}/gtksourceview-4/*
%{_datadir}/gnome-builder
%{_datadir}/metainfo/org.gnome.Builder.appdata.xml
%{_datadir}/gtksourceview-4/styles/builder-dark.style-scheme.xml
%{_datadir}/gtksourceview-4/styles/builder.style-scheme.xml
%{python3_sitelib}/gi/overrides/Ide.py
%{python3_sitelib}/gi/overrides/__pycache__/*
%lang(en) %{_datadir}/doc/gnome-builder/en/

%files devel
%{_includedir}/gnome-builder*/
%{_libdir}/%{name}/pkgconfig/
%{_datadir}/%{name}/gir-1.0/


%changelog
* Tue Feb 02 2021 ovitters <ovitters> 3.38.2-1.mga8
+ Revision: 1674445
- new version 3.38.2

* Thu Dec 31 2020 luigiwalser <luigiwalser> 3.38.1-4.mga8
+ Revision: 1667237
- rebuild for libgit2

* Thu Nov 26 2020 tv <tv> 3.38.1-3.mga8
+ Revision: 1649612
- rebuild for llvm/clang 11.0
+ wally <wally>
- recommend sysprof

* Sun Oct 25 2020 wally <wally> 3.38.1-2.mga8
+ Revision: 1639197
- require typelib(Jsonrpc) (mga#27464)

* Fri Oct 16 2020 ovitters <ovitters> 3.38.1-1.mga8
+ Revision: 1636312
- new version 3.38.1

* Sat Sep 26 2020 tv <tv> 3.38.0-2.mga8
+ Revision: 1630181
- rebuild for new libgladeui

* Sat Sep 12 2020 ovitters <ovitters> 3.38.0-1.mga8
+ Revision: 1625370
- new version 3.38.0

* Sun Sep 06 2020 ovitters <ovitters> 3.37.92-1.mga8
+ Revision: 1623038
- new version 3.37.92

* Fri Aug 07 2020 ovitters <ovitters> 3.37.90-1.mga8
+ Revision: 1611925
- new version 3.37.90
- dropped merged patch 0001-sysprof_bump-to-sysprof-4-ABI.patch

* Mon Aug 03 2020 daviddavid <daviddavid> 3.37.1-1.mga8
+ Revision: 1610769
- add upstream patch to bump to sysprof-4 ABI
- new version 3.37.1
+ ovitters <ovitters>
- rebuild for get rid of pythonegg requires

* Sat Jun 27 2020 ovitters <ovitters> 3.36.1-1.mga8
+ Revision: 1599426
- new version 3.36.1
- dropped merged patch 0001-meson_Add-generated-lsp-enum-header-to-lsp-sources.patch

* Thu May 07 2020 daviddavid <daviddavid> 3.36.0-6.mga8
+ Revision: 1581439
- add upstream to add generated lsp enum header to lsp sources (should fix arm build)

* Thu May 07 2020 daviddavid <daviddavid> 3.36.0-5.mga8
+ Revision: 1581424
- rebuild for new glade 3.36.0

* Fri Apr 03 2020 wally <wally> 3.36.0-4.mga8
+ Revision: 1564172
- fix requires excludes

* Fri Apr 03 2020 ovitters <ovitters> 3.36.0-3.mga8
+ Revision: 1564168
- filter out a require on same package

* Sun Mar 22 2020 tv <tv> 3.36.0-2.mga8
+ Revision: 1558772
- rebuild with llvm 10

* Sun Mar 08 2020 ovitters <ovitters> 3.36.0-1.mga8
+ Revision: 1554872
- new version 3.36.0

* Mon Feb 24 2020 tv <tv> 3.35.91-1.mga8
+ Revision: 1549896
- update license tag
- bump needed versions
- adjust BRs + filelist
+ ovitters <ovitters>
- new version 3.35.91
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Oct 05 2019 ovitters <ovitters> 3.34.1-1.mga8
+ Revision: 1449416
- new version 3.34.1

* Tue Sep 17 2019 tv <tv> 3.34.0-4.mga8
+ Revision: 1443064
- rebuild for llvm-9.0

* Mon Sep 16 2019 tv <tv> 3.34.0-3.mga8
+ Revision: 1442037
- bump release
- rebuild for libpeas

* Tue Sep 10 2019 ovitters <ovitters> 3.34.0-1.mga8
+ Revision: 1439236
- new version 3.34.0

* Thu Sep 05 2019 ovitters <ovitters> 3.33.92-1.mga8
+ Revision: 1437432
- new version 3.33.92

* Sun Aug 11 2019 ovitters <ovitters> 3.33.90-1.mga8
+ Revision: 1428711
- new version 3.33.90

* Wed Aug 07 2019 tv <tv> 3.33.4-1.mga8
+ Revision: 1427849
- new release

* Tue Jul 16 2019 ovitters <ovitters> 3.32.4-1.mga8
+ Revision: 1421814
- new version 3.32.4

* Tue Jul 02 2019 ovitters <ovitters> 3.32.3-1.mga8
+ Revision: 1417606
- new version 3.32.3

* Wed Apr 17 2019 umeabot <umeabot> 3.32.1-3.mga7
+ Revision: 1392272
- Rebuild with meson 0.50.1

* Mon Apr 15 2019 daviddavid <daviddavid> 3.32.1-2.mga7
+ Revision: 1390771
- rebuild for new llvm/clang 8.0

* Thu Apr 11 2019 ovitters <ovitters> 3.32.1-1.mga7
+ Revision: 1388228
- new version 3.32.1

* Wed Mar 13 2019 ovitters <ovitters> 3.32.0-1.mga7
+ Revision: 1375168
- new version 3.32.0

* Sat Mar 09 2019 daviddavid <daviddavid> 3.31.92-1.mga7
+ Revision: 1373113
- new version 3.31.92

* Wed Jan 30 2019 daviddavid <daviddavid> 3.30.3-2.mga7
+ Revision: 1361976
- require libpeas-loader-python3
- enable libide gtk-doc building
- enable help building

* Sun Jan 13 2019 ovitters <ovitters> 3.30.3-1.mga7
+ Revision: 1355809
- new version 3.30.3

* Wed Jan 09 2019 tv <tv> 3.30.2-2.mga7
+ Revision: 1353065
- rebuild with python 3.7
+ ovitters <ovitters>
- new version 3.30.2

* Thu Sep 27 2018 tv <tv> 3.30.1-2.mga7
+ Revision: 1308216
- rebuild for llvm 7.0

* Tue Sep 25 2018 ovitters <ovitters> 3.30.1-1.mga7
+ Revision: 1304067
- new version 3.30.1

* Wed Sep 05 2018 ovitters <ovitters> 3.30.0-1.mga7
+ Revision: 1257255
- new version 3.30.0

* Tue Sep 04 2018 daviddavid <daviddavid> 3.29.92-1.mga7
+ Revision: 1257119
- new version 3.29.92
+ tv <tv>
- need newer sysprof

* Fri Jul 27 2018 ovitters <ovitters> 3.28.4-1.mga7
+ Revision: 1245585
- new version 3.28.4

* Thu Jun 21 2018 ovitters <ovitters> 3.28.3-1.mga7
+ Revision: 1238482
- new version 3.28.3

* Tue May 29 2018 ovitters <ovitters> 3.28.2-1.mga7
+ Revision: 1232899
- new version 3.28.2

* Wed Apr 11 2018 tv <tv> 3.28.1-2.mga7
+ Revision: 1217629
- rebuild with llvm/clang 6.0

* Tue Apr 10 2018 ovitters <ovitters> 3.28.1-1.mga7
+ Revision: 1216942
- new version 3.28.1

* Wed Mar 14 2018 tv <tv> 3.28.0-2.mga7
+ Revision: 1209217
- rebuild with latest gspell

* Wed Mar 14 2018 tv <tv> 3.28.0-1.mga7
+ Revision: 1209175
- BR pkgconfig(enchant) -> pkgconfig(enchant-2)
+ ovitters <ovitters>
- new version 3.28.0

* Mon Mar 12 2018 tv <tv> 3.27.92-1.mga7
+ Revision: 1208656
- BR python3-gobject3
- BuildConflicts with older valgrind-devel (thus unbreaking build)
- fix filelist
- fix install: we use system's template-glib
- package license
- fix doc filelist
- reorder (easier comp with FC)
- recommends more pkgs
- exclude more private libs
- fix filelist
- BR enchant
- bump BR on sysprof
+ ovitters <ovitters>
- new version 3.27.92
- rebuild for devhelp
- new version 3.27.91
- new version 3.27.90
- new version 3.26.4
- new version 3.26.3

* Tue Nov 21 2017 tv <tv> 3.26.2-2.mga7
+ Revision: 1178552
- fix filelist
- rebuild for llvm 5
- bump BR on jsonrpc-glib
- rebuild with latest llvm
+ ovitters <ovitters>
- new version 3.26.2
- new version 3.26.1

* Thu Sep 21 2017 tv <tv> 3.26.0-7.mga7
+ Revision: 1156915
- rebuild with llvm-4.0

* Thu Sep 21 2017 tv <tv> 3.26.0-6.mga7
+ Revision: 1156571
- fix file list + BR libdazzle-1.0 & template-glib-1.0
- "fix" underlinking
- BR bison
- BR flex
- BR pkgconfig(sysprof-ui-2)
- new release
- sort BRs

* Fri Aug 04 2017 tv <tv> 3.24.2-3.mga7
+ Revision: 1134715
- fix build with new find_lang
- rebuild for new python

* Sun Jun 04 2017 akien <akien> 3.24.2-2.mga6
+ Revision: 1106483
- Rebuild for devhelp 3.24.0

* Tue May 09 2017 ovitters <ovitters> 3.24.2-1.mga6
+ Revision: 1099766
- new version 3.24.2

* Mon Apr 10 2017 ovitters <ovitters> 3.24.1-1.mga6
+ Revision: 1096342
- new version 3.24.1
- dropped merged patch 884b8b4f3504b4319cd88c385536ef070d41424c..5806789a23719386ef8cd8bd75f3d24a52cdc5bd.patch
- dropped merged patch 841794b3e4e3c16c70242dbddadce6c5d45378fb..e67c00433aac3cce63e680f052835111456d1a10.patch

* Thu Mar 23 2017 ovitters <ovitters> 3.24.0-1.mga6
+ Revision: 1094538
- enable flatpak support
- add patch to fix linking against enchant (bgo#780420)
- fix linking (bgo#780414)
- new version 3.24.0

* Mon Mar 13 2017 ovitters <ovitters> 3.22.4-3.mga6
+ Revision: 1092344
- recommend flatpak-builder

* Sat Jan 07 2017 tv <tv> 3.22.4-2.mga6
+ Revision: 1080477
- rebuild for llvm+clang 3.9

* Thu Dec 22 2016 ovitters <ovitters> 3.22.4-1.mga6
+ Revision: 1076319
- new version 3.22.4

* Tue Nov 29 2016 ovitters <ovitters> 3.22.3-1.mga6
+ Revision: 1070933
- new version 3.22.3
- new version 3.22.2
+ wally <wally>
- new version 3.22.1
- rediff linking patch

* Mon Oct 17 2016 wally <wally> 3.22.0-2.mga6
+ Revision: 1061303
- filter out plugin .so from provides
- redo linking patch to really fix underlinking

* Sat Sep 24 2016 ovitters <ovitters> 3.22.0-1.mga6
+ Revision: 1055780
- don't byte compile .py files
- new version 3.22.0

* Wed Jun 08 2016 tv <tv> 3.20.4-2.mga6
+ Revision: 1020778
- adjust BRs for latest systemd

* Fri May 06 2016 ovitters <ovitters> 3.20.4-1.mga6
+ Revision: 1009868
- new version 3.20.4

* Thu Apr 28 2016 ovitters <ovitters> 3.20.2-1.mga6
+ Revision: 1007569
- new version 3.20.2

* Wed Mar 23 2016 tv <tv> 3.20.0-1.mga6
+ Revision: 994409
- easy "fix" for underlinking issues...
- new release

* Thu Mar 17 2016 daviddavid <daviddavid> 3.19.90-2.mga6
+ Revision: 992412
- fix requires (drop unwanted fedora's macros {?_isa})
- use new python macros

* Tue Mar 15 2016 tv <tv> 3.19.90-1.mga6
+ Revision: 990755
- rediff patch for new release
- new release
- adjust file list
- add a devel subpkg
- rediff linking patch
- disable unappliable patch
- rebuild for new clang
- rediff patch
- 3.19.4

* Mon Feb 15 2016 luigiwalser <luigiwalser> 3.18.1-5.mga6
+ Revision: 961586
- rebuild for vala

* Tue Jan 12 2016 tv <tv> 3.18.1-4.mga6
+ Revision: 922268
- rebuild for new gnutls

* Wed Jan 06 2016 tv <tv> 3.18.1-3.mga6
+ Revision: 920147
- rebuild for clang 3.7.1

* Thu Dec 17 2015 ovitters <ovitters> 3.18.1-2.mga6
+ Revision: 911519
- require pythonegg(3)(jedi)

* Thu Oct 29 2015 tv <tv> 3.18.1-1.mga6
+ Revision: 896531
- adjust file list
- link with pangoft2 too
- further fix linking
+ ovitters <ovitters>
- new version 3.18.1

* Wed Oct 07 2015 ovitters <ovitters> 3.18.0-2.mga6
+ Revision: 887193
- rebuild for new python3

* Thu Sep 24 2015 tv <tv> 3.18.0-1.mga6
+ Revision: 883242
- patch 0: fix linking
- adjust file list
- add missing BRs
- drop merged patches
- new release

* Wed Aug 05 2015 tv <tv> 3.16.3-2.mga6
+ Revision: 861400
- fix build with libgit2-glib
- rebuild for new llvm

* Mon Jun 22 2015 ovitters <ovitters> 3.16.3-1.mga6
+ Revision: 839875
- imported package gnome-builder

